The pyLife stress subpackage
############################

The ``stress`` subpackage contains all the pyLife modules that deal with stress
resp. load analysis.

There are the two central classes :class:`~pylife.stress.LoadCollective` and
:class:`~pylife.stress.LoadHistogram` to describe load collectives.
